==> RSTouchscreenNG-1.4.16.zip: RSTouchscreenNG/projects/pages/src/lib/web-actions.component.ts <==
/* (C) 2016-2023 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {PrinterState, PrintersState, PrinterAction, WebCall, ServerAction, RepetierState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {RSModal} from "front-ui";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-web-actions",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-empty-sideicon></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-empty-sideicon></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="fa fa-globe"></i> <?php _('Web Actions') ?></rs-headline>
        <div class="content-h1" rsDrag>
          <div>
            <div class="valuelist center-icons margin-leftright">
              <div class="button-icon sep-icon" *ngFor="let f of webCallFiltered" style="min-width:12em">
                <rs-button class="secondary outline full" (hit)="runWebCall(f)">

                  <rs-dyn-icon [icon]="(f.icon ? f.icon : 'fa fa-globe')"></rs-dyn-icon>
                  <h3 class="text" style="padding:8px">
                    {{ f.show_name }}</h3></rs-button>
              </div>
            </div>
            <div *ngIf="webCallFiltered.length===0" class="alert info margin">
              <?php _('No predefined web actions defined!') ?>
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})
export class WebActionsComponent implements OnDestroy {
  printer: PrinterState;
  active: PrinterState = undefined;
  printers$: Observable<PrintersState>;
  webCalls$: Observable<WebCall[]>;
  private webCallsSubscription: SubscriptionLike;
  webCallFiltered: WebCall[] = [];
  webCalls: WebCall[] = [];

  private printersSubscription: SubscriptionLike;

  constructor(public serverAction: ServerAction,
              public printerAction: PrinterAction,
              public modal: RSModal,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.webCalls$ = store.select(s => s.server.webCalls);
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
      this.filterWebcalls();
    });
    this.webCallsSubscription = this.webCalls$.subscribe((w: WebCall[]) => {
      this.webCalls = w;
      this.filterWebcalls();
    });
  }

  filterWebcalls() {
    const a: WebCall[] = [];
    this.webCalls.forEach(x => {
      if (x.show_in_menu && ((this.printer && x.slug === this.printer.slug) || x.slug === "")) {
        a.push(x);
      }
    });
    this.webCallFiltered = a;
  }

  runWebCall(cmd: WebCall) {
    if (cmd.question) {
      this.modal.confirm("<?php _('Security Question') ?>", cmd.question, {}).then(
        (res) => this.serverAction.runWebCall(cmd), () => {
        }
      );
    } else {
      this.serverAction.runWebCall(cmd);
    }
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
    this.webCallsSubscription.unsubscribe();
  }
}

==> RSTouchscreenNG-1.4.17.zip: RSTouchscreenNG/projects/pages/src/lib/web-actions.component.ts <==
/* (C) 2016-2024 Hot-World GmbH & Co. KG <rlittwin@repetier.com>
 All Rights Reserved

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY
 DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 It is allowed to use this code to create or use in products connecting to
 Repetier-Server or to use it for own plugins/modules with Repetier-Server.
 This includes free and commercial products.
 Usage for other products is strictly forbidden.
 */

import {Component, OnDestroy} from "@angular/core";
import {PrinterState, PrintersState, PrinterAction, WebCall, ServerAction, RepetierState, ServerState} from "binding";
import {Observable, SubscriptionLike} from "rxjs";
import {RSModal} from "front-ui";
import {Store} from "@ngrx/store";

@Component({
  // eslint-disable-next-line @angular-eslint/component-selector
  selector: "rs-web-actions",
  template: `
    <rs-page>
      <rs-side>
        <rs-sideicon title="<?php _('Menu') ?>" icon="rs-menu" link="/"></rs-sideicon>
      </rs-side>
      <rs-side>
        <rs-empty-sideicon></rs-empty-sideicon>
      </rs-side>
      <rs-side>
        <rs-empty-sideicon></rs-empty-sideicon>
      </rs-side>
      <main>
        <rs-headline><i class="fa fa-globe"></i> <?php _('Web Actions') ?></rs-headline>
        <div class="content-h1" rsDrag *ngIf="(server$|async).features['touch-web-actions']">
          <div>
            <div class="valuelist center-icons margin-leftright">
              <div class="button-icon sep-icon" *ngFor="let f of webCallFiltered" style="min-width:12em">
                <rs-button class="secondary outline full" (hit)="runWebCall(f)">

                  <rs-dyn-icon [icon]="(f.icon ? f.icon : 'fa fa-globe')"></rs-dyn-icon>
                  <h3 class="text" style="padding:8px">
                    {{ f.show_name }}</h3></rs-button>
              </div>
            </div>
            <div *ngIf="webCallFiltered.length===0" class="alert info margin">
              <?php _('No predefined web actions defined!') ?>
            </div>
          </div>
        </div>
      </main>
    </rs-page>
  `
})
export class WebActionsComponent implements OnDestroy {
  printer: PrinterState;
  active: PrinterState = undefined;
  printers$: Observable<PrintersState>;
  webCalls$: Observable<WebCall[]>;
  server$: Observable<ServerState>;
  private webCallsSubscription: SubscriptionLike;
  webCallFiltered: WebCall[] = [];
  webCalls: WebCall[] = [];

  private printersSubscription: SubscriptionLike;

  constructor(public serverAction: ServerAction,
              public printerAction: PrinterAction,
              public modal: RSModal,
              private store: Store<RepetierState>) {
    this.printers$ = store.select("printers");
    this.webCalls$ = store.select(s => s.server.webCalls);
    this.server$ = store.select("server");
    this.printersSubscription = this.printers$.subscribe((p: PrintersState) => {
      if (p.active) {
        this.printer = p.printers[p.active];
      } else {
        this.printer = undefined;
      }
      this.filterWebcalls();
    });
    this.webCallsSubscription = this.webCalls$.subscribe((w: WebCall[]) => {
      this.webCalls = w;
      this.filterWebcalls();
    });
  }

  filterWebcalls() {
    const a: WebCall[] = [];
    this.webCalls.forEach(x => {
      if (x.show_in_menu && ((this.printer && x.slug === this.printer.slug) || x.slug === "")) {
        a.push(x);
      }
    });
    this.webCallFiltered = a;
  }

  runWebCall(cmd: WebCall) {
    if (cmd.question) {
      this.modal.confirm("<?php _('Security Question') ?>", cmd.question, {}).then(
        (res) => this.serverAction.runWebCall(cmd), () => {
        }
      );
    } else {
      this.serverAction.runWebCall(cmd);
    }
  }

  ngOnDestroy(): void {
    this.printersSubscription.unsubscribe();
    this.webCallsSubscription.unsubscribe();
  }
}
